.. ufs2arco documentation master file, created by
   sphinx-quickstart on Wed Nov 15 16:50:45 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ufs2arco
========

Tools for converting Unified Forecast System (UFS) output to Analysis Ready, Cloud Optimized (ARCO) format

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   installation

.. toctree::
   :maxdepth: 1
   :caption: Examples

   Replay FV3 (1 Degree) <example_replay_fv3>
   Replay MOM6 (1 Degree) <example_replay_mom6>
   Replay CICE6 (1 Degree) <example_replay_cice6>

.. toctree::
   :maxdepth: 1
   :caption: Community

   contributing
   support

.. toctree::
   :maxdepth: 1
   :caption: References

   api
